cookiejar_file

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 1, 2024 License: BSD-3-Clause Imports: 10 Imported by: 0

Documentation

Overview

Package cookiejar_file implements entry repository with file in a append-only manner. user can call EntryRepository.Compact() to reduce file size.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type EntryRepository

type EntryRepository interface {
	cookiejar.EntryRepository
	Compact() (err error)
	Filename() string
}

func NewEntryRepository

func NewEntryRepository(filename string) EntryRepository

NewEntryRepository use filename to store cookies will use `.tmp` as tmp file suffix, and `~` as backupSuffix

Jump to