Documentation
¶
Overview ¶
Package cookiejar_file implements entry repository with file in a append-only manner. user can call EntryRepository.Compact() to reduce file size.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EntryRepository ¶
type EntryRepository interface {
cookiejar.EntryRepository
Compact() (err error)
Filename() string
}
func NewEntryRepository ¶
func NewEntryRepository(filename string) EntryRepository
NewEntryRepository use filename to store cookies will use `.tmp` as tmp file suffix, and `~` as backupSuffix
Click to show internal directories.
Click to hide internal directories.